# PERF01-BP05: Use guidance from your cloud provider

## Description

Leverage cloud provider best practices và documentation.

## Implementation Guidance

- Follow provider well-architected frameworks
- Use provider solution architects
- Attend provider training and events
- Review provider whitepapers
- Engage with provider support

## Risk Level

Low - Ignoring guidance leads to common mistakes.

## Related Best Practices

- [PERF01-BP01](PERF01-BP01-Learn-Available-Services.md)
- [PERF01-BP04](PERF01-BP04-Reference-Architectures.md)
